@@ -46,7 +46,7 @@ def load(path, mode='r', encoding='utf-8', time_unit='100ns'):
     """
     # lab ファイル読み取り
     with open(path, mode=mode, encoding=encoding) as f:
-        lines = [s.strip().split() for s in f.readlines()]
+        lines = [s.strip().split(maxsplit=2) for s in f.readlines()]
     # 入力ファイル末尾の空白行を除去
     while lines[-1] == ['']:
         del lines[-1]
@@ -112,22 +112,33 @@ class Label(UserList):
     def reload(self):
         """
         発音開始時刻を参照して、発音終了時刻を自動補完する。
-        ただし最終行の発音狩猟時刻だけは補完できないため、そのままにする。
+        ただし最終行の発音終了時刻だけは補完できないため、そのままにする。
         """
         for i, phoneme in enumerate(self[:-1]):
             phoneme.end = self[i + 1].start
 
+    def round(self, step_size: int):
+        """
+        時刻を丸める。
+        """
+        for phoneme in self:
+            phoneme.start = round(phoneme.start / step_size) * step_size
+            phoneme.end = round(phoneme.end / step_size) * step_size
+
     def write(self, path_out, mode='w',
-              encoding='utf-8', newline='\n', delimiter=' ', kiritan=False):
+              encoding='utf-8', newline='\n', delimiter=' ', time_unit='100ns'):
         """
         LABファイルを書き出し
         """
-        if kiritan:
-            lines = ['{:.7f} {:.7f} {}'.format(ph.start, ph.end, ph.symbol)
-                     for ph in self]  # 100ns -> 1s 表記変換
-        else:
+        if time_unit == '100ns':
             lines = ['{0}{3}{1}{3}{2}'.format(
                 ph.start, ph.end, ph.symbol, delimiter) for ph in self]
+        elif time_unit in ('s', '1s', 'sec'):
+            lines = ['{:.7f} {:.7f} {}'.format(
+                ph.start, ph.end, ph.symbol) for ph in self]  # 100ns -> 1s 表記変換
+        else:
+            raise ValueError("Argument time_unit must be '100ns' or 's'.")
+
         # ファイル出力
         with open(path_out, mode=mode, encoding=encoding, newline=newline) as f:
             f.write('\n'.join(lines))
@@ -147,6 +158,13 @@ class Phoneme:
     def __str__(self):
         return f'{self.start} {self.end} {self.symbol}'
 
+    @property
+    def duration(self) -> int:
+        """
+        発声時間
+        """
+        return self.end - self.start
+
 
 if __name__ == '__main__':
     main()
