@@ -10,76 +10,138 @@ from copy import deepcopy
 # from pprint import pprint
 from typing import List
 
-
 NOTENUM_TO_NOTENAME_DICT = {
     12: 'C0', 13: 'Db0', 14: 'D0', 15: 'Eb0', 16: 'E0', 17: 'F0',
     18: 'Gb0', 19: 'G0', 20: 'Ab0', 21: 'A0', 22: 'Bb0', 23: 'B0',
-     24: 'C1', 25: 'Db1', 26: 'D1', 27: 'Eb1', 28: 'E1', 29: 'F1',
-     30: 'Gb1', 31: 'G1', 32: 'Ab1', 33: 'A1', 34: 'Bb1', 35: 'B1',
-     36: 'C2', 37: 'Db2', 38: 'D2', 39: 'Eb2', 40: 'E2', 41: 'F2',
-     42: 'Gb2', 43: 'G2', 44: 'Ab2', 45: 'A2', 46: 'Bb2', 47: 'B2',
-     48: 'C3', 49: 'Db3', 50: 'D3', 51: 'Eb3', 52: 'E3', 53: 'F3',
-     54: 'Gb3', 55: 'G3', 56: 'Ab3', 57: 'A3', 58: 'Bb3', 59: 'B3',
-     60: 'C4', 61: 'Db4', 62: 'D4', 63: 'Eb4', 64: 'E4', 65: 'F4',
-     66: 'Gb4', 67: 'G4', 68: 'Ab4', 69: 'A4', 70: 'Bb4', 71: 'B4',
-     72: 'C5', 73: 'Db5', 74: 'D5', 75: 'Eb5', 76: 'E5', 77: 'F5',
-     78: 'Gb5', 79: 'G5', 80: 'Ab5', 81: 'A5', 82: 'Bb5', 83: 'B5',
-     84: 'C6', 85: 'Db6', 86: 'D6', 87: 'Eb6', 88: 'E6', 89: 'F6',
-     90: 'Gb6', 91: 'G6', 92: 'Ab6', 93: 'A6', 94: 'Bb6', 95: 'B6',
-     96: 'C7', 97: 'Db7', 98: 'D7', 99: 'Eb7', 100: 'E7', 101: 'F7',
-     102: 'Gb7', 103: 'G7', 104: 'Ab7', 105: 'A7', 106: 'Bb7', 107: 'B7',
-     108: 'C8', 109: 'Db8', 110: 'D8', 111: 'Eb8', 112: 'E8', 113: 'F8',
-     114: 'Gb8', 115: 'G8', 116: 'Ab8', 117: 'A8', 118: 'Bb8', 119: 'B8',
-     120: 'C9', 121: 'Db9', 122: 'D9', 123: 'Eb9', 124: 'E9', 125: 'F9',
-     126: 'Gb9', 127: 'G9'
+    24: 'C1', 25: 'Db1', 26: 'D1', 27: 'Eb1', 28: 'E1', 29: 'F1',
+    30: 'Gb1', 31: 'G1', 32: 'Ab1', 33: 'A1', 34: 'Bb1', 35: 'B1',
+    36: 'C2', 37: 'Db2', 38: 'D2', 39: 'Eb2', 40: 'E2', 41: 'F2',
+    42: 'Gb2', 43: 'G2', 44: 'Ab2', 45: 'A2', 46: 'Bb2', 47: 'B2',
+    48: 'C3', 49: 'Db3', 50: 'D3', 51: 'Eb3', 52: 'E3', 53: 'F3',
+    54: 'Gb3', 55: 'G3', 56: 'Ab3', 57: 'A3', 58: 'Bb3', 59: 'B3',
+    60: 'C4', 61: 'Db4', 62: 'D4', 63: 'Eb4', 64: 'E4', 65: 'F4',
+    66: 'Gb4', 67: 'G4', 68: 'Ab4', 69: 'A4', 70: 'Bb4', 71: 'B4',
+    72: 'C5', 73: 'Db5', 74: 'D5', 75: 'Eb5', 76: 'E5', 77: 'F5',
+    78: 'Gb5', 79: 'G5', 80: 'Ab5', 81: 'A5', 82: 'Bb5', 83: 'B5',
+    84: 'C6', 85: 'Db6', 86: 'D6', 87: 'Eb6', 88: 'E6', 89: 'F6',
+    90: 'Gb6', 91: 'G6', 92: 'Ab6', 93: 'A6', 94: 'Bb6', 95: 'B6',
+    96: 'C7', 97: 'Db7', 98: 'D7', 99: 'Eb7', 100: 'E7', 101: 'F7',
+    102: 'Gb7', 103: 'G7', 104: 'Ab7', 105: 'A7', 106: 'Bb7', 107: 'B7',
+    108: 'C8', 109: 'Db8', 110: 'D8', 111: 'Eb8', 112: 'E8', 113: 'F8',
+    114: 'Gb8', 115: 'G8', 116: 'Ab8', 117: 'A8', 118: 'Bb8', 119: 'B8',
+    120: 'C9', 121: 'Db9', 122: 'D9', 123: 'Eb9', 124: 'E9', 125: 'F9',
+    126: 'Gb9', 127: 'G9',
+    '12': 'C0', '13': 'Db0', '14': 'D0', '15': 'Eb0', '16': 'E0', '17': 'F0',
+    '18': 'Gb0', '19': 'G0', '20': 'Ab0', '21': 'A0', '22': 'Bb0', '23': 'B0',
+    '24': 'C1', '25': 'Db1', '26': 'D1', '27': 'Eb1', '28': 'E1', '29': 'F1',
+    '30': 'Gb1', '31': 'G1', '32': 'Ab1', '33': 'A1', '34': 'Bb1', '35': 'B1',
+    '36': 'C2', '37': 'Db2', '38': 'D2', '39': 'Eb2', '40': 'E2', '41': 'F2',
+    '42': 'Gb2', '43': 'G2', '44': 'Ab2', '45': 'A2', '46': 'Bb2', '47': 'B2',
+    '48': 'C3', '49': 'Db3', '50': 'D3', '51': 'Eb3', '52': 'E3', '53': 'F3',
+    '54': 'Gb3', '55': 'G3', '56': 'Ab3', '57': 'A3', '58': 'Bb3', '59': 'B3',
+    '60': 'C4', '61': 'Db4', '62': 'D4', '63': 'Eb4', '64': 'E4', '65': 'F4',
+    '66': 'Gb4', '67': 'G4', '68': 'Ab4', '69': 'A4', '70': 'Bb4', '71': 'B4',
+    '72': 'C5', '73': 'Db5', '74': 'D5', '75': 'Eb5', '76': 'E5', '77': 'F5',
+    '78': 'Gb5', '79': 'G5', '80': 'Ab5', '81': 'A5', '82': 'Bb5', '83': 'B5',
+    '84': 'C6', '85': 'Db6', '86': 'D6', '87': 'Eb6', '88': 'E6', '89': 'F6',
+    '90': 'Gb6', '91': 'G6', '92': 'Ab6', '93': 'A6', '94': 'Bb6', '95': 'B6',
+    '96': 'C7', '97': 'Db7', '98': 'D7', '99': 'Eb7', '100': 'E7', '101': 'F7',
+    '102': 'Gb7', '103': 'G7', '104': 'Ab7', '105': 'A7', '106': 'Bb7', '107': 'B7',
+    '108': 'C8', '109': 'Db8', '110': 'D8', '111': 'Eb8', '112': 'E8', '113': 'F8',
+    '114': 'Gb8', '115': 'G8', '116': 'Ab8', '117': 'A8', '118': 'Bb8', '119': 'B8',
+    '120': 'C9', '121': 'Db9', '122': 'D9', '123': 'Eb9', '124': 'E9', '125': 'F9',
+    '126': 'Gb9', '127': 'G9'
 }
 
 # TODO: シャープに対応する。
 NOTENAME_TO_NOTENUM_DICT = {
-    'C0': 12, 'C#0': 13, 'Db0': 13, 'D0': 14, 'D#0': 15, 'Eb0': 15, 'E0': 16, 'F0': 17, 'F#0': 18,
-    'Gb0': 18, 'G0': 19, 'G#0': 20, 'Ab0': 20, 'A0': 21, 'A#0': 22, 'Bb0': 22, 'B0': 23,
-    'C1': 24, 'C#1': 25, 'Db1': 25, 'D1': 26, 'D#1': 27, 'Eb1': 27, 'E1': 28, 'F1': 29, 'F#1': 30,
-    'Gb1': 30, 'G1': 31, 'Ab1': 32, 'A1': 33, 'Bb1': 34, 'B1': 35,
-    'C2': 36, 'Db2': 37, 'D2': 38, 'Eb2': 39, 'E2': 40, 'F2': 41,
-    'Gb2': 42, 'G2': 43, 'Ab2': 44, 'A2': 45, 'Bb2': 46, 'B2': 47,
-    'C3': 48, 'Db3': 49, 'D3': 50, 'Eb3': 51, 'E3': 52, 'F3': 53,
-    'Gb3': 54, 'G3': 55, 'Ab3': 56, 'A3': 57, 'Bb3': 58, 'B3': 59,
-    'C4': 60, 'C#4': 61, 'Db4': 61, 'D4': 62, 'D#4': 63, 'Eb4': 63, 'E4': 64, 'F4': 65, 'F#4': 66,
-    'Gb4': 66, 'G4': 67, 'Ab4': 68, 'A4': 69, 'Bb4': 70, 'B4': 71,
-    'C5': 72, 'Db5': 73, 'D5': 74, 'Eb5': 75, 'E5': 76, 'F5': 77,
-    'Gb5': 78, 'G5': 79, 'Ab5': 80, 'A5': 81, 'Bb5': 82, 'B5': 83,
-    'C6': 84, 'Db6': 85, 'D6': 86, 'Eb6': 87, 'E6': 88, 'F6': 89,
-    'Gb6': 90, 'G6': 91, 'Ab6': 92, 'A6': 93, 'Bb6': 94, 'B6': 95,
-    'C7': 96, 'Db7': 97, 'D7': 98, 'Eb7': 99, 'E7': 100, 'F7': 101,
-    'Gb7': 102, 'G7': 103, 'Ab7': 104, 'A7': 105, 'Bb7': 106, 'B7': 107,
-    'C8': 108, 'Db8': 109, 'D8': 110, 'Eb8': 111, 'E8': 112, 'F8': 113,
-    'Gb8': 114, 'G8': 115, 'Ab8': 116, 'A8': 117, 'Bb8': 118, 'B8': 119,
-    'C9': 120, 'Db9': 121, 'D9': 122, 'Eb9': 123, 'E9': 124, 'F9': 125,
+    'Cb0': 11, 'C0': 12, 'C#0': 13,
+    'Db0': 13, 'D0': 14, 'D#0': 15,
+    'Eb0': 15, 'E0': 16, 'E#0': 17,
+    'Fb0': 16, 'F0': 17, 'F#0': 18,
+    'Gb0': 18, 'G0': 19, 'G#0': 20,
+    'Ab0': 20, 'A0': 21, 'A#0': 22,
+    'Bb0': 22, 'B0': 23, 'B#0': 24,
+
+    'Cb1': 23, 'C1': 24, 'C#1': 25,
+    'Db1': 25, 'D1': 26, 'D#1': 27,
+    'Eb1': 27, 'E1': 28, 'E#1': 29,
+    'Fb1': 28, 'F1': 29, 'F#1': 30,
+    'Gb1': 30, 'G1': 31, 'G#1': 32,
+    'Ab1': 32, 'A1': 33, 'A#1': 34,
+    'Bb1': 34, 'B1': 35, 'B#1': 36,
+
+    'Cb2': 35, 'C2': 36, 'C#2': 37,
+    'Db2': 37, 'D2': 38, 'D#2': 39,
+    'Eb2': 39, 'E2': 40, 'E#2': 41,
+    'Fb2': 40, 'F2': 41, 'F#2': 42,
+    'Gb2': 42, 'G2': 43, 'G#2': 44,
+    'Ab2': 44, 'A2': 45, 'A#2': 46,
+    'Bb2': 46, 'B2': 47, 'B#2': 38,
+
+    'Cb3': 47, 'C3': 48, 'C#3': 49,
+    'Db3': 49, 'D3': 50, 'D#3': 51,
+    'Eb3': 51, 'E3': 52, 'E#3': 53,
+    'Fb3': 52, 'F3': 53, 'F#3': 54,
+    'Gb3': 54, 'G3': 55, 'G#3': 56,
+    'Ab3': 56, 'A3': 57, 'A#3': 58,
+    'Bb3': 58, 'B3': 59, 'B#3': 60,
+
+    'Cb4': 59, 'C4': 60, 'C#4': 61,
+    'Db4': 61, 'D4': 62, 'D#4': 63,
+    'Eb4': 63, 'E4': 64, 'E#4': 65,
+    'Fb4': 64, 'F4': 65, 'F#4': 66,
+    'Gb4': 66, 'G4': 67, 'G#4': 68,
+    'Ab4': 68, 'A4': 69, 'A#4': 70,
+    'Bb4': 70, 'B4': 71, 'B#4': 72,
+
+    'Cb5': 71, 'C5': 72, 'C#5': 73,
+    'Db5': 73, 'D5': 74, 'D#5': 75,
+    'Eb5': 75, 'E5': 76, 'E#5': 77,
+    'Fb5': 76, 'F5': 77, 'F#5': 78,
+    'Gb5': 78, 'G5': 79, 'G#5': 79,
+    'Ab5': 80, 'A5': 81, 'A#5': 82,
+    'Bb5': 82, 'B5': 83, 'B#5': 84,
+
+    'Cb6': 83, 'C6': 84, 'C#6': 85,
+    'Db6': 85, 'D6': 86, 'D#6': 87,
+    'Eb6': 87, 'E6': 88, 'E#6': 89,
+    'Fb6': 88, 'F6': 89, 'F#6': 90,
+    'Gb6': 90, 'G6': 91, 'G#6': 92,
+    'Ab6': 92, 'A6': 93, 'A#6': 94,
+    'Bb6': 94, 'B6': 95, 'B#6': 96,
+
+    'Cb7': 95, 'C7': 96, 'C#7': 97,
+    'Db7': 97, 'D7': 98, 'D#7': 99,
+    'Eb7': 99, 'E7': 100, 'E#7': 101,
+    'Fb7': 100, 'F7': 101, 'F#7': 102,
+    'Gb7': 102, 'G7': 103, 'G#7': 104,
+    'Ab7': 104, 'A7': 105, 'A#7': 106,
+    'Bb7': 106, 'B7': 107, 'B#7': 108,
+
+    'Cb8': 107, 'C8': 108, 'C#8': 109,
+    'Db8': 109, 'D8': 110, 'D#8': 111,
+    'Eb8': 111, 'E8': 112, 'E#8': 113,
+    'Fb8': 112, 'F8': 113, 'F#8': 114,
+    'Gb8': 114, 'G8': 115, 'G#8': 116,
+    'Ab8': 116, 'A8': 117, 'A#8': 118,
+    'Bb8': 118, 'B8': 119, 'B#8': 120,
+
+    'Cb9': 119, 'C9': 120, 'C#9': 121,
+    'Db9': 121, 'D9': 122, 'D#9': 123,
+    'Eb9': 123, 'E9': 124, 'E#9': 125,
+    'Fb9': 124, 'F9': 125, 'F#9': 126,
     'Gb9': 126, 'G9': 127
 }
 
+
 def notenum_as_abc(notenum) -> str:
     """
     音階番号をABC表記に変更する(C1=24, C4=)
     """
-    d = {'24': 'C1', '25': 'Db1', '26': 'D1', '27': 'Eb1', '28': 'E1', '29': 'F1',
-         '30': 'Gb1', '31': 'G1', '32': 'Ab1', '33': 'A1', '34': 'Bb1', '35': 'B1',
-         '36': 'C2', '37': 'Db2', '38': 'D2', '39': 'Eb2', '40': 'E2', '41': 'F2',
-         '42': 'Gb2', '43': 'G2', '44': 'Ab2', '45': 'A2', '46': 'Bb2', '47': 'B2',
-         '48': 'C3', '49': 'Db3', '50': 'D3', '51': 'Eb3', '52': 'E3', '53': 'F3',
-         '54': 'Gb3', '55': 'G3', '56': 'Ab3', '57': 'A3', '58': 'Bb3', '59': 'B3',
-         '60': 'C4', '61': 'Db4', '62': 'D4', '63': 'Eb4', '64': 'E4', '65': 'F4',
-         '66': 'Gb4', '67': 'G4', '68': 'Ab4', '69': 'A4', '70': 'Bb4', '71': 'B4',
-         '72': 'C5', '73': 'Db5', '74': 'D5', '75': 'Eb5', '76': 'E5', '77': 'F5',
-         '78': 'Gb5', '79': 'G5', '80': 'Ab5', '81': 'A5', '82': 'Bb5', '83': 'B5',
-         '84': 'C6', '85': 'Db6', '86': 'D6', '87': 'Eb6', '88': 'E6', '89': 'F6',
-         '90': 'Gb6', '91': 'G6', '92': 'Ab6', '93': 'A6', '94': 'Bb6', '95': 'B6',
-         '96': 'C7', '97': 'Db7', '98': 'D7', '99': 'Eb7', '100': 'E7', '101': 'F7',
-         '102': 'Gb7', '103': 'G7', '104': 'Ab7', '105': 'A7', '106': 'Bb7', '107': 'B7',
-         '108': 'C8', '109': 'Db8', '110': 'D8', '111': 'Eb8', '112': 'E8', '113': 'F8',
-         '114': 'Gb8', '115': 'G8', '116': 'Ab8', '117': 'A8', '118': 'Bb8', '119': 'B8'}
-    return d[str(notenum)]
-
+    # raise DeprecationWarning(
+    #     '関数 utaupy.ust.notenum_as_abc() は utaupy.utils.notenum2notename に名称変更しました。')
+    return NOTENUM_TO_NOTENAME_DICT[int(notenum)]
 
 def load(path: str, encoding: str = 'shift-jis'):
     """
@@ -499,20 +561,6 @@ class Note(UserDict):
     def label(self, label: str):
         self['Label'] = str(label)
 
-    # ここからデータ操作系-----------------------------------------------------
-    def get_by_key(self, key):
-        """
-        ノートの特定の情報を取得
-        UserDictになったのでいずれ消す
-        """
-        return self[key]
-
-    def set_by_key(self, key, x):
-        """ノートの特定の情報を上書きまたは登録
-        UserDictになったのでいずれ消す
-        """
-        self[key] = x
-    # ここまでデータ操作系-----------------------------------------------------
 
     # ここからノート操作系-----------------------------------------------------
     def delete(self):
